@@ -11,7 +11,7 @@ use warnings;
 #my $VERSION="0.1";
 
 #For CVS , use following line
-our $VERSION = sprintf("%d.%04d", "Revision: 2008.0813" =~ /(\d+)\.(\d+)/);
+our $VERSION = sprintf("%d.%04d", "Revision: 2008.0924" =~ /(\d+)\.(\d+)/);
 
 BEGIN {
 
@@ -218,7 +218,7 @@ sub WWW::WhitePages::crs2wp
 
          next if ( defined( $seen->{$columns_in[$map_in{'[DB_NO]'}]} ) );
 
-         $seen->{$columns_in[$map_in{'[DB_NO]'}]} = $columns_in[$map_in{'[ACT_CLNT_ACT_NO]'}];
+         $seen->{$columns_in[$map_in{'[DB_NO]'}]} = 1;
 
          $columns_out[$map_out{'Group'}] = $columns_in[$map_in{'[CC]'}];
 
@@ -278,8 +278,6 @@ sub WWW::WhitePages::crs2wp
 
    $fh_out->close();
 
-   XML::Dumper::pl2xml( $seen, "crs2crs.xml.gz" );
-
 } ## end sub WWW::WhitePages::crs2wp
 
 ##
@@ -289,6 +287,8 @@ sub WWW::WhitePages::00_starter
 {
    chdir $FindBin::Bin;
 
+   return () unless( -f 'wp.csv.gz' );
+
    my $fh_in = IO::Zlib->new( 'wp.csv.gz', 'rb' );
 
    my $csv_in = Text::CSV->new();
@@ -617,178 +617,41 @@ sub WWW::WhitePages::04_tallier
 } ## end sub WWW::WhitePages::04_tallier
 
 ##
-## WWW::WhitePages::wp2crs
+## 98 Remover
 ##
-sub WWW::WhitePages::wp2crs
+sub WWW::WhitePages::98_remover
 {
    chdir $FindBin::Bin;
 
    chdir 'data';
 
-   #my $seen = XML::Dumper::xml2pl( 'wp.xml.gz' );
-
-   my $date_today = Date::Format::time2str( "%Y%m%d", time() );
-
-   my $w_filename = File::Spec->catfile( '..', 'output', 'common_dnl.dat.gz' ); ## wacho demographic
-
-   unlink( $w_filename ) if ( -f $w_filename );
-
-   my $w_fh = IO::Zlib->new( $w_filename, 'wb9' );
-
-   my $w_seq = 1;
-
-   my @w_order =
-   (
-      'transDate', #= 8;
-      'transTime', #= 4;
-      'accountNumber', #= 20;
-      'transCode', #= 2;
-      'sequenceNumber', #= 2;
-      'notUsed1', #= 4;
-      'comment', #= 40;
-      'intExtFLAG', #= 1;
-      'recoverCode', #= 4;
-      'recoverID', #= 8;
-      'notUsed2', #= 2;
-      'mIOPARENT', #= 4;
-      'notUsed3', #= 1;
-      'eol' #= 1
-
-   );
-
-   my $w_pkfmt = 'A8A4A20A2A2A4A40A1A4A8A2A4A1A1';
-
-   my %w_map = ();
-
-   for ( my $i = 0; $i <= $#w_order; $i++ )
-   {
-      $w_map{$w_order[$i]} = $i;
-
-   } ## end for
-
-   my @w_data = ();
-
-   foreach ( @w_order )
-   {
-      push( @w_data, '' );
-
-   } ## end foreach
-
-   $w_data[$w_map{'transDate'}] = $date_today;
-
-   $w_data[$w_map{'accountNumber'}] = '4227093881918480';
-
-   $w_data[$w_map{'transCode'}] = '90';
-
-   $w_data[$w_map{'sequenceNumber'}] = sprintf( "%02d", $w_seq++ % 100 );
-
-   $w_data[$w_map{'comment'}] = '###################';
-
-   $w_data[$w_map{'eol'}] = "\n";
-
-   ##debug## print $w_fh pack( $w_pkfmt, @w_data );
-
-   my $n_filename = File::Spec->catfile( '..', 'output', 'ncofwdease.dat.gz' ); ## nco fwdease
-
-   unlink( $n_filename ) if ( -f $n_filename );
-
-   my $n_fh = IO::Zlib->new( $n_filename, 'wb9' );
-
-   my @n_order =
-   (
-      'recordCode', #= 2;
-      'fileNo', #= 10;
-      'accountID', #= 20;
-      'mascoFile', #= 15;
-      'firmID', #= 10;
-      'forwID', #= 10;
-      'pDate', #= 8;
-      'pCode', #= 8;
-      'pCmt', #= 30;
-      'eol', #= 1;
-
-   );
-
-   my $n_pkfmt = 'A2A10A20A15A10A10A8A8A30A1';
-
-   my %n_map = ();
-
-   for ( my $i = 0; $i <= $#n_order; $i++ )
-   {
-      $n_map{$n_order[$i]} = $i;
-
-   } ## end for
-
-   my @n_data = ();
-
-   foreach ( @n_order )
-   {
-      push( @n_data, '' );
-
-   } ## end foreach
-
-   $n_data[$n_map{'recordCode'}] = '09';
-
-   $n_data[$n_map{'accountID'}] = '4227093881918480';
-
-   $n_data[$n_map{'pDate'}] = $date_today;
-
-   $n_data[$n_map{'pCode'}] = '*XX:X114';
-
-   $n_data[$n_map{'pCmt'}] = 'WHITEPAGE INFO';
-
-   $n_data[$n_map{'eol'}] = "\n";
-
-   ##debug## print $n_fh pack( $n_pkfmt, @n_data );
-
-   ##
-   ## Rattle on
-   ##
-
    my @input = <*.xml.gz>;
 
    foreach my $control_file ( @input )
    {
       my $control = XML::Dumper::xml2pl( $control_file );
 
-      my $w_s = 1;
+      if ( ( ( $control->{'level'} == 0 ) &&
+             ( $control->{'parsed'} == 0 ) &&
+             ( $control->{'reviewed'} == 0 ) &&
+             ( $control->{'reported'} == 1 )
+           ) ||
+           ( ( $control->{'level'} == 1 ) &&
+             ( $control->{'parsed'} == 1 ) &&
+             ( $control->{'reviewed'} == 1 )
+           )
+         )
+      {
+         ##debug##
+         print 'Removing ' . $control_file . "\n";
 
-      my $w_n = 1;
+         unlink( $control_file );
 
-      $control_file =~ m/^(\w+)[.]xml[.]gz$/;
-
-      $w_data[$w_map{'accountNumber'}] = $1;
-
-      $w_data[$w_map{'sequenceNumber'}] = sprintf( "%02d", $w_s++ % 100 );
-
-      $w_data[$w_map{'comment'}] = '###################';
-
-      print $w_fh pack( $w_pkfmt, @w_data );
-
-      $w_data[$w_map{'sequenceNumber'}] = sprintf( "%02d", $w_s++ % 100 );
-
-      $w_data[$w_map{'comment'}] = '# WHITEPAGES LISTING: ' . $w_n;
-
-      print $w_fh pack( $w_pkfmt, @w_data );
-
-      $w_data[$w_map{'sequenceNumber'}] = sprintf( "%02d", $w_s++ % 100 );
-
-      $w_data[$w_map{'comment'}] = '###################';
-
-      print $w_fh pack( $w_pkfmt, @w_data );
-
-      ##debug## print $n_fh pack( $n_pkfmt, @n_data );
+      } ## end if
 
    } ## end foreach
 
-   ##
-   ## Finish
-   ##
-   $w_fh->close();
-
-   $n_fh->close();
-
-} ## end sub WWW::WhitePages::wp2crs
+} ## end sub WWW::WhitePages::98_remover
 
 ##
 ## 99 Cleanup
@@ -803,6 +666,9 @@ sub WWW::WhitePages::99_cleanup
 
    foreach my $control_file ( @input )
    {
+      ##debug##
+      print 'Removing ' . $control_file . "\n";
+
       unlink( $control_file );
 
    } ## end foreach
@@ -836,6 +702,8 @@ WWW::WhitePages::03_reports(); ## run as needed
 
 WWW::WhitePages::04_tallier(); ## run as needed
 
+WWW::WhitePages::98_remover(); ## run as needed
+
 WWW::WhitePages::99_cleanup(); ## run once, when done
 
 =head1 OPTIONS
@@ -913,9 +781,13 @@ The fields output are qw(Type Lastname Firstname House Street City State Zip Pho
 
 This procedure gives you a tally or count.
 
+=item WWW::WhitePages::98_remover();
+
+This procedure cleans the completed control files out the data directory.
+
 =item WWW::WhitePages::99_cleanup();
 
-This procedure cleans the control files out the data directory.
+This procedure cleans all the control files out the data directory.
 
 =back
 
